package com.caimei365.manager.controller.wechat;

import com.caimei365.manager.config.security.ConstantKey;
import com.caimei365.manager.config.security.JwtService;
import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.wechat.WechatArticle;
import com.caimei365.manager.service.wechat.WechatArticleService;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

/**
 * 微信公众号-图文素材
 *
 * @author : Charles
 * @date : 2022/1/6
 */
@RestController
@RequestMapping("/wechat/article")
public class WechatArticleApi {

    @Resource
    private WechatArticleService wechatArticleService;
    @Resource
    private JwtService jwtService;

    /**
     * 获取图文素材列表
     *
     * @param type 类型： 1采美，2呵呵商城
     * @param title 标题
     * @param pageNum  页码
     * @param pageSize 每页大小
     */
    @GetMapping("/list")
    public ResponseJson<PaginationVo<WechatArticle>> articleList(Integer type, String title,
                                                               @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                               @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        return wechatArticleService.getArticleList(type, title, pageNum, pageSize);
    }

    /**
     * 根据ID获取图文素材
     */
    @GetMapping("/{id}")
    public ResponseJson<WechatArticle> getArticle(@PathVariable("id") Integer id) {
        if (null == id || id <= 0) {
            return ResponseJson.error("图文素材Id不能为空！", null);
        }
        return wechatArticleService.getArticle(id);
    }

    /**
     * 根据ID更新图文素材
     */
    @PostMapping("/update/{id}")
    public ResponseJson<Void> updateArticle(HttpServletRequest request, @PathVariable("id") Integer id, @RequestBody WechatArticle article) {
        if (null == id || id <= 0) {
            return ResponseJson.error("图文素材Id不能为空！", null);
        }
        String token = request.getHeader(ConstantKey.TOKEN_NAME);
        String username = jwtService.getUsername(token);
        return wechatArticleService.updateArticle(id, article, username);
    }

    /**
     * 添加图文素材
     */
    @PostMapping("/create")
    public ResponseJson<Void> addArticle(HttpServletRequest request, @RequestBody WechatArticle article) {
        String token = request.getHeader(ConstantKey.TOKEN_NAME);
        String username = jwtService.getUsername(token);
        return wechatArticleService.addArticle(article, username);
    }

    /**
     * 根据ID删除图文素材
     */
    @PostMapping("/delete/{id}")
    public ResponseJson<Void> deleteArticle(@PathVariable("id") Integer id) {
        if (null == id || id <= 0) {
            return ResponseJson.error("图文素材Id不能为空！", null);
        }
        return wechatArticleService.deleteArticle(id);
    }
}
